@@ -98,6 +98,7 @@ the mode line."
   "`ess-transcript-mode' for SAS."
   (interactive)
   (SAS-mode)
+  (setq mode-name "ESS[LOG]")
   (ess-transcript-minor-mode 1)
   (toggle-read-only t)) ;; to protect the buffer.
 
@@ -441,35 +442,35 @@ number."
 ;	      "\\>")
 ;	     font-lock-keyword-face)
 ;
-       ;; SAS statements
+       ;; SAS base and SAS/Graph statements
        (cons (concat ;"\\<"
 	      (regexp-opt
 	       '(
 		 "do" "to" "by" "goto" ; "go"
 		"abort" "and" "array" "assess" "attrib" 
-		"baseline" "bayes" "between" 
-		"change" "class" "contains" "contrast"
-		"delete" "display" "dm" "drop"
+		"baseline" "bayes" "between" "block" "bubble" "bubble2"
+		"change" "choro" "class" "contains" "contrast"
+		"delete" "display" "dm" "donut" "drop"
 		"else" "error" "exchange" "exclude" 
 		"file" "filename" "format" "freq"
 		 "footnote" "footnote1" "footnote2" "footnote3" "footnote4" "footnote5" 
 		 "footnote6" "footnote7" "footnote8" "footnote9" "footnote10"
-		"goptions" ; "ge" "gt" 
-		"hazardratio"
+		"goptions" "grid" ; "ge" "gt" 
+		"hazardratio" "hbar" "hbar3d"
 		"id" "if" "index" "infile" "informat" "input" ; "is" rarely used, but common false pos.
 		"keep" 
 		"label" "length" "libname" "like" "link" "lsmeans" ; "le" "lt"
 		"manova" "means" "merge" "missing" "model" "modify" 
 		"not" "null" ; "ne" "note" 
 		"ods" "options" "or" "output" "otherwise" 
-		"pageby" "plot" "put" 
+		"pageby" "pie" "pie3d" "plot" "plot2" "prism" "put" 
 		"random" "rename" "repeated" "retain"
-		"same" "save" "select" "set" "skip" "strata" "sum" "sumby"
+		"same" "save" "scatter" "select" "set" "skip" "star" "strata" "sum" "sumby" "surface"
 		"table" "tables" "test" "then" "time"
 		 "title" "title1" "title2" "title3" "title4" "title5" 
 		 "title6" "title7" "title8" "title9" "title10"
 		"update"
-		"value" "var"
+		"value" "var" "vbar" "vbar3d"
 		"weight" "where" "window" "with" 
 		; "x"
 		 ) 'words)) ;"\\>")
@@ -975,16 +976,19 @@ opening /* appears.  returns 0 otherwise."
       (beep)
       (message "Missing Run Statement."))))
 
-
-(defun sas-fix-life-tables (start end)
+(defun sas-fix-life-tables ()
   "Remove censored and duplicate observations from life tables generated by
 Proc Lifetest.  Operates on current region.  A major space saver if there is
 heavy censoring."
-  (interactive "r")
-  (save-excursion
-    (shell-command-on-region
-     start end
-     "sed \"\\?          *\\.          *\\.          *\\.    ?d\"" t)))
+  (interactive)
+    (goto-char (point-min))
+(while (re-search-forward "^.*[ ]+[.][ ]+[.][ ]+[.][ ]+.*$" nil t)
+     (replace-match "" nil nil)))
+;  (save-excursion
+;    (shell-command-on-region
+;     start end
+;     "sed '/[ ][.][ ]/d'" t)))
+     ;;"sed \"\\?          *\\.          *\\.          *\\.    ?d\"" t)))
 ;;(vip-goto-line 1)
 ;;(setq ex-g-flag nil
 ;;ex-g-variant nil)
@@ -1034,16 +1038,21 @@ If START is given this will be the number for the current page."
   (save-excursion
     (goto-char (point-min))
     (if (looking-at "\f") (delete-char 1))
-    (replace-regexp "^\\(.+\\)\f" "\\1\n\f\n")
+    ;(replace-regexp "^\\(.+\\)\f" "\\1\n\f\n")
+(while (re-search-forward "^\\(.+\\)\f" nil t)
+     (replace-match "\\1\n\f\n" nil nil))
     (goto-char (point-min))
-    (replace-regexp "^\f\\(.+\\)" "\f\n\\1")
+    ;(replace-regexp "^\f\\(.+\\)" "\f\n\\1")
+(while (re-search-forward "^\f\\(.+\\)" nil t)
+     (replace-match "\f\n\\1" nil nil))
+;    (goto-char (point-min))
+    ;(replace-regexp " $" "")
+;(while (re-search-forward "$" nil t)
+;     (replace-match "" nil nil))
     (goto-char (point-min))
-    (replace-regexp "
-$" "")
-    (goto-char (point-min))
-    (replace-regexp "
-\\([^
-\\$]+\\)" "\n\\1")
+    ;(replace-regexp " \\([^\\$]+\\)" "\n\\1")
+(while (re-search-forward " \\([^\\$]+\\)" nil t)
+     (replace-match "\n\\1" nil nil))
     (goto-char (point-max))
     (if (not (bobp))
         (progn (backward-char 1)
