@@ -229,6 +229,62 @@ default using the first entry of `ess-swv-pdflatex-commands' and display it."
  (ess-swv-PDF))
 
 
+;; AUCTeX integration.  This is independent of this library, but it fits
+;; here nonetheless since it's an alternative way of Sweave'ing without
+;; starting iESS.
+(defun ess-swv-add-TeX-commands ()
+  "Add commands to AUCTeX's \\[TeX-command-list]."
+  (unless (and (featurep 'tex-site) (featurep 'tex))
+    (error "AUCTeX does not seem to be loaded"))
+  (add-to-list 'TeX-command-list
+	       '("Sweave" "R CMD Sweave %t"
+		 TeX-run-command nil (latex-mode) :help
+		 "Run Sweave") t)
+  (add-to-list 'TeX-command-list
+	       '("LaTeXSweave" "%l %(mode) %s"
+		 TeX-run-TeX nil (latex-mode) :help
+		 "Run LaTeX after Sweave") t)
+  (setq TeX-command-default "Sweave")
+  (mapc (lambda (suffix)
+	  (add-to-list 'TeX-file-extensions suffix))
+	'("nw" "Snw" "Rnw")))
+
+(defun ess-swv-remove-TeX-commands ()
+  "Remove commands from AUCTeX's \\[TeX-command-list]."
+  (let ((swv-cmds '("Sweave" "LaTeXSweave"))
+	tex-cmds cmdpos)
+    (mapc (lambda (x)
+	    (setq tex-cmds (mapcar 'car TeX-command-list))
+	    (setq cmdpos (position x tex-cmds :test #'string-equal))
+	    (when cmdpos
+	      (setq TeX-command-list
+	    	    (remove (nth cmdpos TeX-command-list)
+	    		    TeX-command-list))))
+	  swv-cmds)))
+
+(defun ess-swv-plug-into-AUCTeX ()
+  "Add commands to AUCTeX's \\[TeX-command-list] to sweave the current noweb
+file and latex the result."
+  (if ess-swv-plug-into-AUCTeX-p
+      (add-hook 'Rnw-mode-hook 'ess-swv-add-TeX-commands)
+    (remove-hook 'Rnw-mode-hook 'ess-swv-add-TeX-commands)
+    (ess-swv-remove-TeX-commands)))
+(when ess-swv-plug-into-AUCTeX-p (ess-swv-plug-into-AUCTeX))
+
+(defun ess-swv-toggle-plug-into-AUCTeX ()
+  "Toggle inclusion of commands to sweave noweb files and latex the results in
+\\[TeX-command-list] on and off.  Commands are added via \\[Rnw-mode-hook]."
+  (interactive)
+  (unless (and (featurep 'tex-site) (featurep 'tex))
+    (error "AUCTeX does not seem to be loaded"))
+  (setq ess-swv-plug-into-AUCTeX-p (not ess-swv-plug-into-AUCTeX-p))
+  (ess-swv-plug-into-AUCTeX)
+  (TeX-normal-mode t)
+  (if ess-swv-plug-into-AUCTeX-p
+      (message "Sweave and LaTeXSweave are known in AUCTeX.")
+    (message "Sweave and LaTeXSweave are no longer known in AUCTeX.")))
+
+
 ;;; Now bind some keys.
 (define-key noweb-minor-mode-map "\M-ns" 'ess-swv-weave)
 (define-key noweb-minor-mode-map "\M-nT" 'ess-swv-tangle)
@@ -250,6 +306,8 @@ default using the first entry of `ess-swv-pdflatex-commands' and display it."
      ["PDF(LaTeX)" ess-swv-PDF t]
      ["PS (dvips)" ess-swv-PS  t]
      ["Insert Sexpr" ess-insert-Sexpr t]
+     ["AUCTeX Interface" ess-swv-toggle-plug-into-AUCTeX
+     :style toggle :selected ess-swv-plug-into-AUCTeX-p]
      ))
 
 (if (featurep 'xemacs)
